# mypy-boto3-emr<a id="mypy-boto3-emr"></a>

[![PyPI - mypy-boto3-emr](https://img.shields.io/pypi/v/mypy-boto3-emr.svg?color=blue)](https://pypi.org/project/mypy-boto3-emr)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-emr.svg?color=blue)](https://pypi.org/project/mypy-boto3-emr)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-emr?color=blue)](https://pypistats.org/packages/mypy-boto3-emr)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.EMR 1.17.71](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/emr.html#EMR)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-buider 4.12.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-emr docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-emr](#mypy-boto3-emr)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

## How to install<a id="how-to-install"></a>

Install `boto3-stubs` for `EMR` service.

```bash
python -m pip install boto3-stubs[emr]
```

## Usage<a id="usage"></a>

### VSCode<a id="vscode"></a>

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[emr]` in your environment:
  `python -m pip install 'boto3-stubs[emr]'`

Both type checking and auto-complete should work for `EMR` service. No explicit
type annotations required, write your `boto3` code as usual.

### PyCharm<a id="pycharm"></a>

- Install `boto-stubs[emr]` in your environment:
  `python -m pip install 'boto3-stubs[emr]'`

Both type checking and auto-complete should work for `EMR` service. No explicit
type annotations required, write your `boto3` code as usual. Auto-complete can
be slow on big projects or if you have a lot of installed `boto3-stubs`
submodules.

### Other IDEs<a id="other-ides"></a>

Not tested, but as long as your IDE support `mypy` or `pyright`, everything
should work.

### mypy<a id="mypy"></a>

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[emr]` in your environment:
  `python -m pip install 'boto3-stubs[emr]'`
- Run `mypy` as usual

Type checking should work for `EMR` service. No explicit type annotations
required, write your `boto3` code as usual.

### pyright<a id="pyright"></a>

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[emr]` in your environment:
  `python -m pip install 'boto3-stubs[emr]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `EMR` service. No explicit type annotations
required, write your `boto3` code as usual.

## Explicit type annotations<a id="explicit-type-annotations"></a>

### Client annotations<a id="client-annotations"></a>

`EMRClient` provides annotations for `boto3.client("emr")`.

```python
import boto3

from mypy_boto3_emr import EMRClient

client: EMRClient = boto3.client("emr")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: EMRClient = session.client("emr")
```

### Paginators annotations<a id="paginators-annotations"></a>

`mypy_boto3_emr.paginator` module contains type annotations for all paginators.

```python
from mypy_boto3_emr import EMRClient
from mypy_boto3_emr.paginator import (
    ListBootstrapActionsPaginator,
    ListClustersPaginator,
    ListInstanceFleetsPaginator,
    ListInstanceGroupsPaginator,
    ListInstancesPaginator,
    ListNotebookExecutionsPaginator,
    ListSecurityConfigurationsPaginator,
    ListStepsPaginator,
    ListStudioSessionMappingsPaginator,
    ListStudiosPaginator,
)

client: EMRClient = boto3.client("emr")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_bootstrap_actions_paginator: ListBootstrapActionsPaginator = client.get_paginator("list_bootstrap_actions")
list_clusters_paginator: ListClustersPaginator = client.get_paginator("list_clusters")
list_instance_fleets_paginator: ListInstanceFleetsPaginator = client.get_paginator("list_instance_fleets")
list_instance_groups_paginator: ListInstanceGroupsPaginator = client.get_paginator("list_instance_groups")
list_instances_paginator: ListInstancesPaginator = client.get_paginator("list_instances")
list_notebook_executions_paginator: ListNotebookExecutionsPaginator = client.get_paginator("list_notebook_executions")
list_security_configurations_paginator: ListSecurityConfigurationsPaginator = client.get_paginator("list_security_configurations")
list_steps_paginator: ListStepsPaginator = client.get_paginator("list_steps")
list_studio_session_mappings_paginator: ListStudioSessionMappingsPaginator = client.get_paginator("list_studio_session_mappings")
list_studios_paginator: ListStudiosPaginator = client.get_paginator("list_studios")
```

### Waiters annotations<a id="waiters-annotations"></a>

`mypy_boto3_emr.waiter` module contains type annotations for all waiters.

```python
from mypy_boto3_emr import EMRClient
from mypy_boto3_emr.waiter import (
    ClusterRunningWaiter,
    ClusterTerminatedWaiter,
    StepCompleteWaiter,
)

client: EMRClient = boto3.client("emr")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
cluster_running_waiter: ClusterRunningWaiter = client.get_waiter("cluster_running")
cluster_terminated_waiter: ClusterTerminatedWaiter = client.get_waiter("cluster_terminated")
step_complete_waiter: StepCompleteWaiter = client.get_waiter("step_complete")
```

### Literals<a id="literals"></a>

`mypy_boto3_emr.literals` module contains literals extracted from shapes that
can be used in user code for type checking.

```python
from mypy_boto3_emr.literals import (
    ActionOnFailure,
    AdjustmentType,
    AuthMode,
    AutoScalingPolicyState,
    AutoScalingPolicyStateChangeReasonCode,
    CancelStepsRequestStatus,
    ClusterRunningWaiterName,
    ClusterState,
    ClusterStateChangeReasonCode,
    ClusterTerminatedWaiterName,
    ComparisonOperator,
    ComputeLimitsUnitType,
    ExecutionEngineType,
    IdentityType,
    InstanceCollectionType,
    InstanceFleetState,
    InstanceFleetStateChangeReasonCode,
    InstanceFleetType,
    InstanceGroupState,
    InstanceGroupStateChangeReasonCode,
    InstanceGroupType,
    InstanceRoleType,
    InstanceState,
    InstanceStateChangeReasonCode,
    JobFlowExecutionState,
    ListBootstrapActionsPaginatorName,
    ListClustersPaginatorName,
    ListInstanceFleetsPaginatorName,
    ListInstanceGroupsPaginatorName,
    ListInstancesPaginatorName,
    ListNotebookExecutionsPaginatorName,
    ListSecurityConfigurationsPaginatorName,
    ListStepsPaginatorName,
    ListStudioSessionMappingsPaginatorName,
    ListStudiosPaginatorName,
    MarketType,
    NotebookExecutionStatus,
    OnDemandCapacityReservationPreference,
    OnDemandCapacityReservationUsageStrategy,
    OnDemandProvisioningAllocationStrategy,
    PlacementGroupStrategy,
    RepoUpgradeOnBoot,
    ScaleDownBehavior,
    SpotProvisioningAllocationStrategy,
    SpotProvisioningTimeoutAction,
    Statistic,
    StepCancellationOption,
    StepCompleteWaiterName,
    StepExecutionState,
    StepState,
    StepStateChangeReasonCode,
    Unit,
)

def check_value(value: ActionOnFailure) -> bool:
    ...
```

### Typed dictionaries<a id="typed-dictionaries"></a>

`mypy_boto3_emr.type_defs` module contains structures and shapes assembled to
typed dictionaries for additional type checking.

```python
from mypy_boto3_emr.type_defs import (
    AddInstanceFleetOutputTypeDef,
    AddInstanceGroupsOutputTypeDef,
    AddJobFlowStepsOutputTypeDef,
    ApplicationTypeDef,
    AutoScalingPolicyDescriptionTypeDef,
    AutoScalingPolicyStateChangeReasonTypeDef,
    AutoScalingPolicyStatusTypeDef,
    AutoScalingPolicyTypeDef,
    BlockPublicAccessConfigurationMetadataTypeDef,
    BlockPublicAccessConfigurationTypeDef,
    BootstrapActionConfigTypeDef,
    BootstrapActionDetailTypeDef,
    CancelStepsInfoTypeDef,
    CancelStepsOutputTypeDef,
    CloudWatchAlarmDefinitionTypeDef,
    ClusterStateChangeReasonTypeDef,
    ClusterStatusTypeDef,
    ClusterSummaryTypeDef,
    ClusterTimelineTypeDef,
    ClusterTypeDef,
    CommandTypeDef,
    ComputeLimitsTypeDef,
    ConfigurationTypeDef,
    CreateSecurityConfigurationOutputTypeDef,
    CreateStudioOutputTypeDef,
    DescribeClusterOutputTypeDef,
    DescribeJobFlowsOutputTypeDef,
    DescribeNotebookExecutionOutputTypeDef,
    DescribeSecurityConfigurationOutputTypeDef,
    DescribeStepOutputTypeDef,
    DescribeStudioOutputTypeDef,
    EbsBlockDeviceConfigTypeDef,
    EbsBlockDeviceTypeDef,
    EbsConfigurationTypeDef,
    EbsVolumeTypeDef,
    Ec2InstanceAttributesTypeDef,
    ExecutionEngineConfigTypeDef,
    FailureDetailsTypeDef,
    GetBlockPublicAccessConfigurationOutputTypeDef,
    GetManagedScalingPolicyOutputTypeDef,
    GetStudioSessionMappingOutputTypeDef,
    HadoopJarStepConfigTypeDef,
    HadoopStepConfigTypeDef,
    InstanceFleetConfigTypeDef,
    InstanceFleetModifyConfigTypeDef,
    InstanceFleetProvisioningSpecificationsTypeDef,
    InstanceFleetStateChangeReasonTypeDef,
    InstanceFleetStatusTypeDef,
    InstanceFleetTimelineTypeDef,
    InstanceFleetTypeDef,
    InstanceGroupConfigTypeDef,
    InstanceGroupDetailTypeDef,
    InstanceGroupModifyConfigTypeDef,
    InstanceGroupStateChangeReasonTypeDef,
    InstanceGroupStatusTypeDef,
    InstanceGroupTimelineTypeDef,
    InstanceGroupTypeDef,
    InstanceResizePolicyTypeDef,
    InstanceStateChangeReasonTypeDef,
    InstanceStatusTypeDef,
    InstanceTimelineTypeDef,
    InstanceTypeConfigTypeDef,
    InstanceTypeDef,
    InstanceTypeSpecificationTypeDef,
    JobFlowDetailTypeDef,
    JobFlowExecutionStatusDetailTypeDef,
    JobFlowInstancesConfigTypeDef,
    JobFlowInstancesDetailTypeDef,
    KerberosAttributesTypeDef,
    KeyValueTypeDef,
    ListBootstrapActionsOutputTypeDef,
    ListClustersOutputTypeDef,
    ListInstanceFleetsOutputTypeDef,
    ListInstanceGroupsOutputTypeDef,
    ListInstancesOutputTypeDef,
    ListNotebookExecutionsOutputTypeDef,
    ListSecurityConfigurationsOutputTypeDef,
    ListStepsOutputTypeDef,
    ListStudioSessionMappingsOutputTypeDef,
    ListStudiosOutputTypeDef,
    ManagedScalingPolicyTypeDef,
    MetricDimensionTypeDef,
    ModifyClusterOutputTypeDef,
    NotebookExecutionSummaryTypeDef,
    NotebookExecutionTypeDef,
    OnDemandCapacityReservationOptionsTypeDef,
    OnDemandProvisioningSpecificationTypeDef,
    PaginatorConfigTypeDef,
    PlacementGroupConfigTypeDef,
    PlacementTypeTypeDef,
    PortRangeTypeDef,
    PutAutoScalingPolicyOutputTypeDef,
    ResponseMetadataTypeDef,
    RunJobFlowOutputTypeDef,
    ScalingActionTypeDef,
    ScalingConstraintsTypeDef,
    ScalingRuleTypeDef,
    ScalingTriggerTypeDef,
    ScriptBootstrapActionConfigTypeDef,
    SecurityConfigurationSummaryTypeDef,
    SessionMappingDetailTypeDef,
    SessionMappingSummaryTypeDef,
    ShrinkPolicyTypeDef,
    SimpleScalingPolicyConfigurationTypeDef,
    SpotProvisioningSpecificationTypeDef,
    StartNotebookExecutionOutputTypeDef,
    StepConfigTypeDef,
    StepDetailTypeDef,
    StepExecutionStatusDetailTypeDef,
    StepStateChangeReasonTypeDef,
    StepStatusTypeDef,
    StepSummaryTypeDef,
    StepTimelineTypeDef,
    StepTypeDef,
    StudioSummaryTypeDef,
    StudioTypeDef,
    SupportedProductConfigTypeDef,
    TagTypeDef,
    VolumeSpecificationTypeDef,
    WaiterConfigTypeDef,
)

def get_structure() -> AddInstanceFleetOutputTypeDef:
    return {
      ...
    }
```

## Versioning<a id="versioning"></a>

`mypy-boto3-emr` version is the same as related `boto3` version and follows
[PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

## Documentation<a id="documentation"></a>

All type annotations can be found in
[mypy-boto3-emr docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr/)

## Support and contributing<a id="support-and-contributing"></a>

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
